@@ -267,6 +267,7 @@ class DirectChannel(RequestWrapper):
     def wsc_save_donation(self, codicedonatore=None, codicecampagna=None, codicecentro=None, codicecanale=None, codicebambino=None,
                           codiceprogetto=None, codiceconto=None, importo=None, metodo=None, note=None, dataoperazione=None, datavaluta=None,
                           idregolare=None, idweb=None, codicetransazione=None, tipo=None, evento=None):
+        
         payload = {
             "env": self.env,
             "application": self.application,
@@ -282,7 +283,7 @@ class DirectChannel(RequestWrapper):
                 "codiceBambino": codicebambino,
                 "codiceProgetto": codiceprogetto,
                 "codiceConto": codiceconto,
-                "importo": importo,
+                "importo": ("%s" % importo).replace('.',','),
                 "metodo": metodo,
                 "note": note,
                 "dataOperazione": dataoperazione,
@@ -368,7 +369,7 @@ class DirectChannel(RequestWrapper):
             }
         }
         headers = {'content-type': 'application/json'}
-        url = "{0}/{1}".format(self.url, 'wsc_save_privacy.ashx')
+        url = "{0}/{1}".format(self.url, 'wsc_set_spec.ashx')
         return self._handle_data(self._send_request(url=url, payload=payload, headers=headers, debug=self.debug))
 
 
